import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import React, { Fragment, forwardRef } from 'react';
import PropTypes from 'prop-types';
import Icon from '../Icon';
import { apiAttributes, formatDuration } from '../helpers';
import { jsx } from "@theme-ui/core";
var DetailsFact = forwardRef(function (_ref, ref) {
  var data = _ref.data,
      rest = _objectWithoutProperties(_ref, ["data"]);

  var type = data.type,
      icon = data.icon,
      prefix = data.prefix;
  var key;
  var value;
  var count;

  switch (type) {
    case 'AttributeAdjust':
      {
        var text = data.text,
            factValue = data.value,
            target = data.target;
        var attribute = !text && target && apiAttributes[target];
        key = attribute ? "".concat(attribute, " Increase") : text;
        value = "".concat(!text || text.endsWith('Increase') ? '+' : '').concat(Number(factValue).toLocaleString());
        break;
      }

    case 'Buff':
      {
        var duration = data.duration,
            status = data.status,
            description = data.description,
            applyCount = data.apply_count;

        if (duration) {
          key = jsx(Fragment, null, status, jsx("span", {
            sx: {
              ml: '2px'
            }
          }, "(".concat(formatDuration(duration), ")")));
        } else {
          key = status;
        }

        value = description;
        count = applyCount;
        break;
      }

    case 'BuffConversion':
      {
        var source = data.source,
            _target = data.target,
            percent = data.percent;
        key = "Gain ".concat(apiAttributes[_target], " Based on a Percentage of ").concat(apiAttributes[source]);
        value = "".concat(percent, "%");
        break;
      }

    case 'ComboField':
      {
        var _text = data.text,
            fieldType = data.field_type;
        key = _text;
        value = fieldType;
        break;
      }

    case 'ComboFinisher':
      {
        var _text2 = data.text,
            _percent = data.percent,
            finisherType = data.finisher_type;
        key = _text2;
        value = "".concat(finisherType).concat(_percent !== undefined && _percent !== 0 && _percent !== 100 ? " (".concat(_percent, "% Chance)") : '');
        break;
      }

    case 'Damage':
      {
        var _text3 = data.text,
            hitCount = data.hit_count,
            dmgMultiplier = data.dmg_multiplier;

        if (hitCount > 1) {
          key = jsx(Fragment, null, _text3, jsx("span", {
            sx: {
              ml: '2px'
            }
          }, "(".concat(hitCount, "x)")));
        } else {
          key = _text3;
        }

        value = Math.round(1047.5 * 1000 * (dmgMultiplier / 2597));
        break;
      }

    case 'Distance':
      {
        var _text4 = data.text,
            distance = data.distance;
        key = _text4;
        value = distance;
        break;
      }

    case 'Duration':
      {
        var _text5 = data.text,
            _duration = data.duration;
        key = _text5;
        value = _duration;
        break;
      }

    case 'Heal':
      {
        var _text6 = data.text,
            _hitCount = data.hit_count;
        key = _text6;
        value = "".concat(_hitCount, "x");
        break;
      }

    case 'HealingAdjust':
      {
        var _text7 = data.text,
            _hitCount2 = data.hit_count;
        key = _text7;
        value = "".concat(_hitCount2, "x");
        break;
      }

    case 'NoData':
      {
        var _text8 = data.text;
        value = _text8;
        break;
      }

    case 'Number':
      {
        var _text9 = data.text,
            _factValue = data.value;
        key = _text9;
        value = _factValue;
        break;
      }

    case 'Percent':
      {
        var _text10 = data.text,
            _percent2 = data.percent;
        key = _text10;
        value = "".concat(_percent2, "%");
        break;
      }

    case 'PrefixedBuff':
      {
        var _text11 = data.text,
            _duration2 = data.duration,
            _status = data.status,
            _description = data.description,
            _applyCount = data.apply_count;

        if (_duration2) {
          key = jsx(Fragment, null, _status, jsx("span", {
            sx: {
              ml: '2px'
            }
          }, "(".concat(_duration2, "s)")));
        } else {
          key = _text11;
        }

        value = _description;
        count = _applyCount;
        break;
      }

    case 'Radius':
      {
        var _text12 = data.text,
            _distance = data.distance;
        key = _text12;
        value = _distance;
        break;
      }

    case 'Range':
      {
        var _text13 = data.text,
            _factValue2 = data.value;
        key = _text13;
        value = Number(_factValue2).toLocaleString();
        break;
      }

    case 'Recharge':
      {
        var _text14 = data.text,
            _factValue3 = data.value;
        key = _text14;
        value = _factValue3;
        break;
      }

    case 'StunBreak':
      {
        value = 'Breaks Stun';
        break;
      }

    case 'Time':
      {
        var _text15 = data.text,
            _duration3 = data.duration;
        key = _text15;
        value = "".concat(_duration3, " second").concat(_duration3 > 1 ? 's' : '');
        break;
      }

    case 'Unblockable':
      {
        var _text16 = data.text;
        value = _text16;
        break;
      }

    default:
      {
        console.warn('Unknown fact type', data);
        var _text17 = data.text,
            _factValue4 = data.value;

        if (value === true) {
          value = _text17;
        } else {
          key = _text17;
          value = _factValue4;
        }

        break;
      }
  }

  if (!key && !value) {
    return null;
  }

  return jsx("div", _extends({
    sx: {
      display: 'flex',
      flexDirection: 'row',
      alignItems: 'center'
    }
  }, rest, {
    ref: ref
  }), jsx("div", {
    sx: {
      display: 'flex',
      flexDirection: 'row',
      fontSize: '30px'
    }
  }, (prefix === null || prefix === void 0 ? void 0 : prefix.icon) && jsx(Icon, {
    src: prefix.icon,
    applyCount: prefix.apply_count
  }), icon && jsx(Icon, {
    src: icon,
    applyCount: count
  })), jsx("div", {
    sx: {
      ml: '4px',
      color: 'gw2.details.muted'
    }
  }, key, key ? ': ' : '', value));
});
DetailsFact.propTypes = {
  data: PropTypes.object.isRequired
};
DetailsFact.displayName = 'DetailsFact';
export default DetailsFact;
//# sourceMappingURL=DetailsFact.js.map