import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import React, { forwardRef } from 'react';
import PropTypes from 'prop-types';
import { jsx } from "@theme-ui/core";
var REGEX = new RegExp('<c=@([^>]+?>[^<>]+?)(?:</c>|$)', 'g');

var renderFlavor = function renderFlavor(text) {
  var parts = text.replace(/<br\s*?\/?\s*?>/g, '\n').split(REGEX);

  for (var i = 1; i < parts.length; i += 2) {
    var _parts$i$split = parts[i].split('>'),
        _parts$i$split2 = _slicedToArray(_parts$i$split, 2),
        type = _parts$i$split2[0],
        textPart = _parts$i$split2[1];

    if (type) {
      var color = void 0;

      switch (type) {
        case 'ability':
          color = null;
          break;

        case 'abilitytype':
          color = 'abilityType';
          break;

        case 'reminder':
          color = 'muted';
          break;

        default:
          color = type;
          break;
      }

      parts[i] = [textPart, color];
    } else {
      parts[i] = textPart;
    }
  }

  return jsx(React.Fragment, null, parts.filter(function (part) {
    return !!part;
  }).map(function (part, index) {
    if (Array.isArray(part)) {
      var _part = _slicedToArray(part, 2),
          _textPart = _part[0],
          _color = _part[1];

      if (_color) {
        return jsx("span", {
          key: index,
          sx: {
            color: "gw2.details.".concat(_color)
          }
        }, _textPart);
      }

      return _textPart;
    }

    return part;
  }));
};

var DetailsText = forwardRef(function (_ref, ref) {
  var Component = _ref.component,
      LineComponent = _ref.lineComponent,
      lineProps = _ref.lineProps,
      lines = _ref.lines,
      rest = _objectWithoutProperties(_ref, ["component", "lineComponent", "lineProps", "lines"]);

  return jsx(Component, _extends({}, rest, {
    ref: ref
  }), lines.filter(function (line) {
    return !!line;
  }).map(function (line, index) {
    return jsx(LineComponent, _extends({
      key: index
    }, lineProps), React.isValidElement(line) ? line : renderFlavor(line));
  }));
});
DetailsText.propTypes = {
  component: PropTypes.elementType,
  lines: PropTypes.arrayOf(PropTypes.node).isRequired,
  lineComponent: PropTypes.elementType,
  lineProps: PropTypes.object
};
DetailsText.defaultProps = {
  component: 'div',
  lineComponent: 'div',
  lineProps: {}
};
DetailsText.displayName = 'DetailsText';
export default DetailsText;
//# sourceMappingURL=DetailsText.js.map