import _extends from "@babel/runtime/helpers/extends";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React, { forwardRef } from 'react';
import PropTypes from 'prop-types';
import camelCase from 'lodash.camelcase';
import Tooltip from '../Tooltip';
import DetailsHeader from '../DetailsHeader';
import DetailsText from '../DetailsText';
import IconWithText from '../IconWithText';
import WikiLink from '../WikiLink';
import Error from '../Error';
import { useColorModeHighlightSuffix } from '../helpers';
import { jsx } from "@theme-ui/core";
var Effect = forwardRef(function (_ref, ref) {
  var type = _ref.type,
      name = _ref.name,
      displayName = _ref.displayName,
      description = _ref.description,
      component = _ref.component,
      disableTooltip = _ref.disableTooltip,
      disableIcon = _ref.disableIcon,
      disableText = _ref.disableText,
      disableLink = _ref.disableLink,
      inline = _ref.inline,
      wikiLinkProps = _ref.wikiLinkProps,
      tooltipProps = _ref.tooltipProps,
      errorProps = _ref.errorProps,
      className = _ref.className,
      rest = _objectWithoutProperties(_ref, ["type", "name", "displayName", "description", "component", "disableTooltip", "disableIcon", "disableText", "disableLink", "inline", "wikiLinkProps", "tooltipProps", "errorProps", "className"]);

  var highlightSuffix = useColorModeHighlightSuffix();

  if (!type || !name || typeof description === 'undefined') {
    return jsx(Error, _extends({
      name: "Invalid ".concat(type || 'Effect').concat(name ? " ".concat(name) : ''),
      message: "Error: No data for ".concat(type || 'Effect').concat(name ? " ".concat(name) : ''),
      disableTooltip: disableTooltip,
      disableIcon: disableIcon,
      disableText: disableText,
      inline: inline,
      iconProps: {
        name: '404'
      },
      className: className
    }, errorProps, {
      style: _objectSpread({}, errorProps === null || errorProps === void 0 ? void 0 : errorProps.style, {}, rest.style),
      sx: _objectSpread({}, errorProps === null || errorProps === void 0 ? void 0 : errorProps.sx, {}, rest.sx)
    }));
  }

  return jsx(Tooltip, _extends({
    content: jsx(React.Fragment, null, jsx(DetailsHeader, null, displayName || name), description && jsx(DetailsText, {
      lines: [description]
    })),
    disabled: disableTooltip
  }, tooltipProps), jsx(IconWithText, _extends({
    component: component,
    text: disableLink ? displayName || name : jsx(WikiLink, _extends({
      to: displayName || name
    }, wikiLinkProps, {
      sx: _objectSpread({
        color: 'inherit',
        '&:hover': {
          color: "gw2.effect.".concat(camelCase(type)).concat(highlightSuffix)
        }
      }, wikiLinkProps === null || wikiLinkProps === void 0 ? void 0 : wikiLinkProps.sx)
    })),
    disableIcon: disableIcon,
    disableText: disableText,
    inline: inline,
    className: className
  }, rest, {
    iconProps: _objectSpread({
      name: "".concat(type, ".").concat(name)
    }, rest.iconProps),
    sx: _objectSpread({
      color: "gw2.effect.".concat(camelCase(type))
    }, rest.sx),
    ref: ref
  })));
});
Effect.propTypes = {
  type: PropTypes.string.isRequired,
  name: PropTypes.string.isRequired,
  displayName: PropTypes.string,
  description: PropTypes.string,
  component: PropTypes.elementType,
  disableTooltip: PropTypes.bool,
  disableIcon: PropTypes.bool,
  disableText: PropTypes.bool,
  disableLink: PropTypes.bool,
  inline: PropTypes.bool,
  tooltipProps: PropTypes.object,
  wikiLinkProps: PropTypes.object,
  errorProps: PropTypes.object
};
Effect.defaultProps = {
  displayName: null,
  description: undefined,
  component: undefined,
  disableTooltip: false,
  disableIcon: false,
  disableText: false,
  disableLink: false,
  inline: true,
  tooltipProps: {},
  wikiLinkProps: {},
  errorProps: {}
};
Effect.displayName = 'Effect';
export default Effect;
//# sourceMappingURL=Effect.js.map