import _extends from "@babel/runtime/helpers/extends";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React, { forwardRef } from 'react';
import PropTypes from 'prop-types';
import withLoading from '../withLoading/index';
import Tooltip from '../Tooltip';
import IconWithText from '../IconWithText';
import WikiLink from '../WikiLink';
import ItemDetails from '../ItemDetails';
import { useColorModeHighlightSuffix } from '../helpers';
import { jsx } from "@theme-ui/core";
var Item = forwardRef(function (_ref, ref) {
  var _tooltipProps$contain;

  var id = _ref.id,
      count = _ref.count,
      data = _ref.data,
      component = _ref.component,
      upgrades = _ref.upgrades,
      disableIcon = _ref.disableIcon,
      disableText = _ref.disableText,
      disableLink = _ref.disableLink,
      disableTooltip = _ref.disableTooltip,
      inline = _ref.inline,
      tooltipProps = _ref.tooltipProps,
      wikiLinkProps = _ref.wikiLinkProps,
      rest = _objectWithoutProperties(_ref, ["id", "count", "data", "component", "upgrades", "disableIcon", "disableText", "disableLink", "disableTooltip", "inline", "tooltipProps", "wikiLinkProps"]);

  var highlightSuffix = useColorModeHighlightSuffix();
  var name = data.name,
      icon = data.icon,
      rarity = data.rarity,
      type = data.type,
      _data$details = data.details;
  _data$details = _data$details === void 0 ? {} : _data$details;
  var detailsType = _data$details.type;
  return jsx(Tooltip, _extends({
    content: jsx(ItemDetails, {
      data: data,
      count: count,
      upgrades: upgrades && upgrades.map(function (_ref2, index) {
        var upgradeId = _ref2.id,
            upgradeData = _ref2.data,
            upgradeLoading = _ref2.loading,
            upgradeError = _ref2.error,
            upgradeBonusCount = _ref2.count;
        return jsx("div", {
          key: "".concat(upgradeId, "-").concat(index),
          sx: _objectSpread({
            mt: '16px'
          }, index < upgrades.length && {
            mb: '16px'
          })
        }, jsx(ItemDetails, {
          upgrade: true,
          id: upgradeId,
          loading: upgradeLoading,
          error: upgradeError,
          data: upgradeData,
          upgradeBonusCount: upgradeBonusCount
        }));
      })
    }),
    disabled: disableTooltip
  }, tooltipProps, {
    containerProps: _objectSpread({}, tooltipProps.containerProps, {
      sx: _objectSpread({
        maxWidth: 353
      }, (_tooltipProps$contain = tooltipProps.containerProps) === null || _tooltipProps$contain === void 0 ? void 0 : _tooltipProps$contain.sx)
    })
  }), jsx(IconWithText, _extends({
    component: component,
    icon: icon,
    text: jsx(React.Fragment, null, count > 1 && "".concat(count, " "), disableLink ? name : jsx(WikiLink, _extends({
      to: name
    }, wikiLinkProps, {
      sx: _objectSpread({
        color: 'inherit',
        '&:hover': {
          color: "gw2.rarity.".concat(rarity.toLowerCase()).concat(highlightSuffix)
        }
      }, wikiLinkProps === null || wikiLinkProps === void 0 ? void 0 : wikiLinkProps.sx)
    }))),
    disableIcon: disableIcon,
    disableText: disableText,
    inline: inline
  }, rest, {
    iconProps: _objectSpread({}, type && detailsType && {
      name: "".concat(type, ".").concat(detailsType)
    }, {
      applyCount: count,
      applyCountProps: {
        sx: {
          top: '0.1em',
          right: '0.1em',
          bottom: 'initial',
          color: "#fee49a"
        }
      }
    }, rest.iconProps),
    sx: _objectSpread({
      color: "gw2.rarity.".concat(rarity.toLowerCase())
    }, rest.sx),
    ref: ref
  })));
});
Item.propTypes = {
  id: PropTypes.number,
  count: PropTypes.number,
  component: PropTypes.elementType,
  data: PropTypes.object.isRequired,
  disableIcon: PropTypes.bool,
  disableText: PropTypes.bool,
  disableLink: PropTypes.bool,
  disableTooltip: PropTypes.bool,
  inline: PropTypes.bool,
  tooltipProps: PropTypes.object,
  wikiLinkProps: PropTypes.object,
  upgrades: PropTypes.arrayOf(PropTypes.shape({
    data: PropTypes.object,
    loading: PropTypes.bool,
    error: PropTypes.shape({
      code: PropTypes.string,
      name: PropTypes.string,
      message: PropTypes.string
    }),
    count: PropTypes.number
  }))
};
Item.defaultProps = {
  id: null,
  count: null,
  component: undefined,
  disableIcon: false,
  disableText: false,
  disableLink: false,
  disableTooltip: false,
  inline: true,
  tooltipProps: {},
  wikiLinkProps: {},
  upgrades: null
};
Item.displayName = 'Item';
export default withLoading()(Item);
//# sourceMappingURL=Item.js.map