import _toConsumableArray from "@babel/runtime/helpers/toConsumableArray";
import _extends from "@babel/runtime/helpers/extends";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";

var _ref4;

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React, { forwardRef } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import IconWithText from '../IconWithText';
import WikiLink from '../WikiLink';
import Error from '../Error';
import professions from '../data/professions.json';
import { useColorModeHighlightSuffix } from '../helpers';
import { jsx } from "@theme-ui/core";
var Profession = forwardRef(function (_ref, ref) {
  var propsName = _ref.name,
      eliteSpecialization = _ref.eliteSpecialization,
      component = _ref.component,
      disableTooltip = _ref.disableTooltip,
      disableIcon = _ref.disableIcon,
      disableText = _ref.disableText,
      disableLink = _ref.disableLink,
      inline = _ref.inline,
      wikiLinkProps = _ref.wikiLinkProps,
      tooltipProps = _ref.tooltipProps,
      errorProps = _ref.errorProps,
      rest = _objectWithoutProperties(_ref, ["name", "eliteSpecialization", "component", "disableTooltip", "disableIcon", "disableText", "disableLink", "inline", "wikiLinkProps", "tooltipProps", "errorProps"]);

  var highlightSuffix = useColorModeHighlightSuffix();
  var name;

  if (eliteSpecialization) {
    name = (Object.entries(professions).find(function (_ref2) {
      var _ref3 = _slicedToArray(_ref2, 2),
          professionEliteSpecializations = _ref3[1];

      return professionEliteSpecializations.includes(eliteSpecialization);
    }) || [])[0];
  } else if (Object.keys(professions).includes(propsName)) {
    name = propsName;
  }

  if (!name) {
    return jsx(Error, _extends({
      name: "Invalid Profession".concat(propsName ? " ".concat(propsName) : ''),
      message: "Error: No data for Profession".concat(propsName ? " ".concat(propsName) : '').concat(propsName && eliteSpecialization ? ' and' : '').concat(eliteSpecialization ? " elite specialization ".concat(eliteSpecialization) : ''),
      disableTooltip: disableTooltip,
      disableIcon: disableIcon,
      disableText: disableText,
      inline: inline,
      iconProps: {
        name: '404'
      }
    }, errorProps, {
      style: _objectSpread({}, rest.style, {}, errorProps === null || errorProps === void 0 ? void 0 : errorProps.style),
      className: cx(rest.className, errorProps.className),
      sx: _objectSpread({}, rest.sx, {}, errorProps === null || errorProps === void 0 ? void 0 : errorProps.sx)
    }));
  }

  return jsx(IconWithText, _extends({
    component: component,
    text: disableLink ? eliteSpecialization || name : jsx(WikiLink, _extends({
      to: eliteSpecialization || name
    }, wikiLinkProps, {
      sx: _objectSpread({
        color: 'inherit',
        '&:hover': {
          color: "gw2.profession.".concat(name.toLowerCase()).concat(highlightSuffix)
        }
      }, wikiLinkProps === null || wikiLinkProps === void 0 ? void 0 : wikiLinkProps.sx)
    })),
    disableIcon: disableIcon,
    disableText: disableText,
    inline: inline
  }, rest, {
    iconProps: _objectSpread({
      name: "Profession.".concat(eliteSpecialization || name)
    }, rest.iconProps),
    sx: _objectSpread({
      color: "gw2.profession.".concat(name.toLowerCase())
    }, rest.sx),
    ref: ref
  }));
});
Profession.propTypes = {
  name: PropTypes.oneOf(Object.keys(professions)),
  eliteSpecialization: PropTypes.oneOf((_ref4 = []).concat.apply(_ref4, _toConsumableArray(Object.values(professions)))),
  component: PropTypes.elementType,
  disableTooltip: PropTypes.bool,
  disableIcon: PropTypes.bool,
  disableText: PropTypes.bool,
  disableLink: PropTypes.bool,
  inline: PropTypes.bool,
  tooltipProps: PropTypes.object,
  wikiLinkProps: PropTypes.object,
  errorProps: PropTypes.object
};
Profession.defaultProps = {
  name: null,
  eliteSpecialization: null,
  component: undefined,
  disableTooltip: false,
  disableIcon: false,
  disableText: false,
  disableLink: false,
  inline: true,
  tooltipProps: {},
  wikiLinkProps: {},
  errorProps: {}
};
Profession.displayName = 'Profession';
export default Profession;
//# sourceMappingURL=Profession.js.map