import _extends from "@babel/runtime/helpers/extends";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React, { forwardRef } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import IconWithText from '../IconWithText';
import WikiLink from '../WikiLink';
import Error from '../Error';
import races from '../data/races.json';
import { useColorModeHighlightSuffix } from '../helpers';
import { jsx } from "@theme-ui/core";
var Race = forwardRef(function (_ref, ref) {
  var name = _ref.name,
      component = _ref.component,
      disableTooltip = _ref.disableTooltip,
      disableIcon = _ref.disableIcon,
      disableText = _ref.disableText,
      disableLink = _ref.disableLink,
      inline = _ref.inline,
      wikiLinkProps = _ref.wikiLinkProps,
      tooltipProps = _ref.tooltipProps,
      errorProps = _ref.errorProps,
      rest = _objectWithoutProperties(_ref, ["name", "component", "disableTooltip", "disableIcon", "disableText", "disableLink", "inline", "wikiLinkProps", "tooltipProps", "errorProps"]);

  var highlightSuffix = useColorModeHighlightSuffix();

  if (!name || !races.includes(name)) {
    return jsx(Error, _extends({
      name: "Invalid Race".concat(name ? " ".concat(name) : ''),
      message: "Error: No data for Race".concat(name ? " ".concat(name) : ''),
      disableTooltip: disableTooltip,
      disableIcon: disableIcon,
      disableText: disableText,
      inline: inline,
      iconProps: {
        name: '404'
      }
    }, errorProps, {
      style: _objectSpread({}, rest.style, {}, errorProps === null || errorProps === void 0 ? void 0 : errorProps.style),
      className: cx(rest.className, errorProps.className),
      sx: _objectSpread({}, rest.sx, {}, errorProps === null || errorProps === void 0 ? void 0 : errorProps.sx)
    }));
  }

  return jsx(IconWithText, _extends({
    component: component,
    text: disableLink ? name : jsx(WikiLink, _extends({
      to: name
    }, wikiLinkProps, {
      sx: _objectSpread({
        color: 'inherit',
        '&:hover': {
          color: "gw2.race.".concat(name.toLowerCase()).concat(highlightSuffix)
        }
      }, wikiLinkProps === null || wikiLinkProps === void 0 ? void 0 : wikiLinkProps.sx)
    })),
    disableIcon: disableIcon,
    disableText: disableText,
    inline: inline
  }, rest, {
    iconProps: _objectSpread({
      name: "Race.".concat(name)
    }, rest.iconProps),
    sx: _objectSpread({
      color: "gw2.race.".concat(name.toLowerCase())
    }, rest.sx),
    ref: ref
  }));
});
Race.propTypes = {
  name: PropTypes.oneOf(races).isRequired,
  component: PropTypes.elementType,
  disableTooltip: PropTypes.bool,
  disableIcon: PropTypes.bool,
  disableText: PropTypes.bool,
  disableLink: PropTypes.bool,
  inline: PropTypes.bool,
  tooltipProps: PropTypes.object,
  wikiLinkProps: PropTypes.object,
  errorProps: PropTypes.object
};
Race.defaultProps = {
  component: undefined,
  disableTooltip: false,
  disableIcon: false,
  disableText: false,
  disableLink: false,
  inline: true,
  tooltipProps: {},
  wikiLinkProps: {},
  errorProps: {}
};
Race.displayName = 'Race';
export default Race;
//# sourceMappingURL=Race.js.map