import _extends from "@babel/runtime/helpers/extends";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React, { forwardRef } from 'react';
import PropTypes from 'prop-types';
import withLoading from '../withLoading/index';
import Tooltip from '../Tooltip';
import TooltipContainer from '../TooltipContainer';
import IconWithText from '../IconWithText';
import WikiLink from '../WikiLink';
import AbilityDetails from '../AbilityDetails';
import { specializations, useColorModeHighlightSuffix } from '../helpers';
import { jsx } from "@theme-ui/core";
var Trait = forwardRef(function (_ref, ref) {
  var id = _ref.id,
      data = _ref.data,
      component = _ref.component,
      disableIcon = _ref.disableIcon,
      disableText = _ref.disableText,
      disableLink = _ref.disableLink,
      disableTooltip = _ref.disableTooltip,
      inline = _ref.inline,
      tooltipProps = _ref.tooltipProps,
      wikiLinkProps = _ref.wikiLinkProps,
      inactive = _ref.inactive,
      rest = _objectWithoutProperties(_ref, ["id", "data", "component", "disableIcon", "disableText", "disableLink", "disableTooltip", "inline", "tooltipProps", "wikiLinkProps", "inactive"]);

  var highlightSuffix = useColorModeHighlightSuffix();
  var name = data.name,
      icon = data.icon,
      specialization = data.specialization,
      skills = data.skills,
      slot = data.slot;

  var _ref2 = specialization && Object.entries(specializations).find(function (_ref4) {
    var _ref5 = _slicedToArray(_ref4, 2),
        specializationIds = _ref5[1];

    return specializationIds.includes(specialization);
  }) || [],
      _ref3 = _slicedToArray(_ref2, 1),
      profession = _ref3[0];

  return jsx(Tooltip, _extends({
    render: jsx(React.Fragment, null, jsx(TooltipContainer, skills && {
      sx: {
        borderColor: '#537ca5'
      }
    }, jsx(AbilityDetails, {
      data: data
    })), skills && skills.map(function (skill) {
      return jsx(TooltipContainer, {
        key: "".concat(skill.id),
        sx: {
          mt: '6px'
        }
      }, jsx(AbilityDetails, {
        data: skill
      }));
    })),
    disabled: disableTooltip
  }, tooltipProps), jsx(IconWithText, _extends({
    component: component,
    icon: icon,
    text: disableLink ? name : jsx(WikiLink, _extends({
      to: name
    }, wikiLinkProps, {
      sx: _objectSpread({
        color: 'inherit',
        '&:hover': {
          color: "gw2.profession.".concat(profession).concat(highlightSuffix)
        }
      }, wikiLinkProps === null || wikiLinkProps === void 0 ? void 0 : wikiLinkProps.sx)
    })),
    disableIcon: disableIcon,
    disableText: disableText,
    inline: inline
  }, rest, {
    iconProps: _objectSpread({
      zoom: 13,
      inactive: inactive,
      hexagon: slot === 'Minor'
    }, rest.iconProps),
    sx: _objectSpread({
      color: "gw2.profession.".concat(profession)
    }, rest.sx),
    ref: ref
  })));
});
Trait.propTypes = {
  id: PropTypes.number,
  component: PropTypes.elementType,
  data: PropTypes.object.isRequired,
  disableIcon: PropTypes.bool,
  disableText: PropTypes.bool,
  disableLink: PropTypes.bool,
  disableTooltip: PropTypes.bool,
  inline: PropTypes.bool,
  tooltipProps: PropTypes.object,
  wikiLinkProps: PropTypes.object,
  inactive: PropTypes.bool
};
Trait.defaultProps = {
  id: null,
  component: undefined,
  disableIcon: false,
  disableText: false,
  disableLink: false,
  disableTooltip: false,
  inline: true,
  tooltipProps: {},
  wikiLinkProps: {},
  inactive: false
};
Trait.displayName = 'Trait';
export default withLoading()(Trait);
//# sourceMappingURL=Trait.js.map