import _toConsumableArray from "@babel/runtime/helpers/toConsumableArray";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _extends from "@babel/runtime/helpers/extends";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React, { forwardRef, Fragment, useState, useCallback, useEffect } from 'react';
import PropTypes from 'prop-types';
import withLoading from '../withLoading';
import Tooltip from '../Tooltip';
import Icon from '../Icon';
import TraitLineConnector, { Paths } from '../TraitLineConnector';
import { jsx } from "@theme-ui/core";

var renderTraitLineConnector = function renderTraitLineConnector() {
  var _ref = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {},
      css = _ref.css,
      rest = _objectWithoutProperties(_ref, ["css"]);

  return jsx(TraitLineConnector, _extends({}, rest, {
    css: _objectSpread({
      alignSelf: 'stretch',
      flexGrow: 1,
      minWidth: 13,
      maxWidth: 36
    }, css)
  }));
};

var TraitLine = forwardRef(function (_ref2, ref) {
  var id = _ref2.id,
      TraitComponent = _ref2.traitComponent,
      defaultSelected = _ref2.defaultSelected,
      propsSelected = _ref2.selected,
      onSelect = _ref2.onSelect,
      selectable = _ref2.selectable,
      resettable = _ref2.resettable,
      onReset = _ref2.onReset,
      _ref2$data = _ref2.data,
      background = _ref2$data.background,
      name = _ref2$data.name,
      minorTraits = _ref2$data.minor_traits,
      majorTraits = _ref2$data.major_traits,
      ignoredComponent = _ref2.component,
      ignoredDisableIcon = _ref2.disableIcon,
      ignoredDisableText = _ref2.disableText,
      ignoredDisableTooltip = _ref2.disableTooltip,
      ignoredInline = _ref2.inline,
      rest = _objectWithoutProperties(_ref2, ["id", "traitComponent", "defaultSelected", "selected", "onSelect", "selectable", "resettable", "onReset", "data", "component", "disableIcon", "disableText", "disableTooltip", "inline"]);

  var _useState = useState(defaultSelected),
      _useState2 = _slicedToArray(_useState, 2),
      uncontrolledSelected = _useState2[0],
      setUncontrolledSelected = _useState2[1];

  useEffect(function () {
    setUncontrolledSelected(defaultSelected);
  }, _toConsumableArray(defaultSelected));
  var controlled = typeof onSelect === 'function';
  var selected;

  if (controlled) {
    selected = propsSelected;
  } else if (selectable) {
    selected = uncontrolledSelected;
  } else {
    selected = defaultSelected || propsSelected;
  }

  var renderMinorTrait = useCallback(function (_ref3) {
    var minorTraitId = _ref3.id;
    return jsx(TraitComponent, {
      key: minorTraitId,
      id: minorTraitId,
      sx: {
        fontSize: '40px',
        display: 'inline-flex',
        color: 'rgba(255,255,255,0.5)'
      },
      iconProps: {
        hexagon: true
      },
      disableText: true,
      inline: false
    });
  }, TraitComponent);
  var renderMajorTrait = useCallback(function (_ref4) {
    var tier = _ref4.tier,
        majorTraitId = _ref4.id,
        isSelected = _ref4.selected,
        majorTraitIndex = _ref4.index;
    return jsx(TraitComponent, _objectSpread({
      key: majorTraitId,
      id: majorTraitId,
      sx: _objectSpread({
        fontSize: '37px',
        display: 'inline-flex',
        color: 'rgba(255,255,255,0.5)'
      }, !isSelected && (controlled || selectable) && {
        cursor: 'pointer'
      }),
      disableText: true,
      inline: false,
      inactive: !isSelected
    }, !isSelected && (controlled || selectable) && {
      onClick: function onClick(event) {
        event.preventDefault();

        if (controlled) {
          onSelect({
            tier: tier,
            id: majorTraitId,
            index: majorTraitIndex
          });
        } else {
          var selectedIndexToReplace = selected.findIndex(function (selectedMajorTraitId) {
            return majorTraits.slice(tier * 3, tier * 3 + 3).includes(selectedMajorTraitId);
          });

          if (selectedIndexToReplace !== -1) {
            setUncontrolledSelected(selected.map(function (value, index) {
              return index === selectedIndexToReplace ? majorTraitId : value;
            }));
          } else {
            var selectedIndexBelowToAppend = tier > 0 && selected.findIndex(function (selectedMajorTraitId) {
              return majorTraits.slice((tier - 1) * 3, (tier - 1) * 3 + 3).includes(selectedMajorTraitId);
            });

            if (selectedIndexBelowToAppend !== -1) {
              var newSelected = _toConsumableArray(selected);

              newSelected.splice(selectedIndexBelowToAppend + 1, 0, majorTraitId);
              setUncontrolledSelected(newSelected);
            } else {
              var selectedIndexAboveToPrepend = tier < 2 && selected.findIndex(function (selectedMajorTraitId) {
                return majorTraits.slice((tier + 1) * 3, (tier + 1) * 3 + 3).includes(selectedMajorTraitId);
              });

              if (selectedIndexAboveToPrepend !== -1) {
                var _newSelected = _toConsumableArray(selected);

                _newSelected.splice(selectedIndexBelowToAppend, 0, majorTraitId);

                setUncontrolledSelected(_newSelected);
              } else {
                setUncontrolledSelected([].concat(_toConsumableArray(selected), [majorTraitId]));
              }
            }
          }
        }
      }
    }));
  }, [TraitComponent, controlled, selectable].concat(_toConsumableArray(selected)));
  return jsx("div", _extends({
    css: {
      position: 'relative',
      width: '100%',
      maxWidth: 650,
      height: 135,
      border: '1px solid #0b0e14',
      backgroundColor: 'rgb(0,0,0)',
      display: 'flex',
      boxSizing: 'border-box',
      overflow: 'hidden',
      '::before': {
        content: '""',
        position: 'absolute',
        minWidth: '100%',
        width: 460,
        height: '100%',
        backgroundPosition: 'left bottom',
        backgroundRepeat: 'no-repeat',
        backgroundImage: "url('".concat(background, "')"),
        right: 0
      }
    }
  }, rest, {
    ref: ref
  }), jsx("div", {
    css: {
      position: 'absolute',
      minWidth: '100%',
      height: '100%',
      right: 0,
      display: 'flex'
    }
  }, jsx("div", {
    css: {
      width: 168,
      filter: 'drop-shadow(2px 2px 5px black)',
      display: 'flex',
      alignItems: 'center'
    }
  }, jsx(Tooltip, {
    content: name
  }, jsx("span", {
    css: {
      position: 'absolute',
      marginLeft: 73,
      height: 55,
      width: 95,
      boxSizing: 'border-box',
      '&, ::before, ::after': {
        borderWidth: 0,
        borderStyle: 'solid',
        borderColor: 'rgba(255,255,255,0.5)'
      },
      '&': {
        borderLeftWidth: 2,
        borderRightWidth: 2
      },
      '::before, ::after': {
        content: "''",
        position: 'absolute',
        width: 64,
        height: 64,
        transform: 'scaleY(0.5774) rotate(-45deg)',
        left: 12
      },
      '::before': {
        top: -33.5,
        borderTopWidth: 3,
        borderRightWidth: 3
      },
      '::after': {
        bottom: -33.5,
        borderBottomWidth: 3,
        borderLeftWidth: 3
      }
    }
  }))), jsx("div", {
    sx: {
      py: '6px'
    },
    css: {
      display: 'flex',
      maxWidth: 430,
      paddingRight: '6px',
      flexGrow: 1,
      justifyContent: 'space-between',
      alignItems: 'center',
      position: 'relative'
    }
  }, majorTraits.reduce(function (array, item, index) {
    return index % 3 === 0 ? [].concat(_toConsumableArray(array), [[item]]) : [].concat(_toConsumableArray(array.slice(0, -1)), [[].concat(_toConsumableArray(array.slice(-1)[0]), [item])]);
  }, []).map(function (majorTraitsChunk, tier) {
    var selectedMajorTraitIndex = majorTraitsChunk.findIndex(function (majorTraitId) {
      return selected.includes(majorTraitId);
    });
    var path = Object.values(Paths)[selectedMajorTraitIndex];
    return jsx(Fragment, {
      key: tier
    }, tier === 0 && renderTraitLineConnector({
      css: {
        maxWidth: 33
      }
    }), renderMinorTrait({
      id: minorTraits[tier],
      tier: tier
    }), renderTraitLineConnector(path !== undefined ? {
      end: path
    } : {
      disabled: true
    }), jsx("div", {
      sx: {
        display: 'flex',
        flexDirection: 'column',
        height: '100%',
        justifyContent: 'space-between',
        alignItems: 'center'
      }
    }, majorTraitsChunk.map(function (majorTraitId, majorTraitIndex) {
      return renderMajorTrait({
        tier: tier,
        id: majorTraitId,
        selected: majorTraitIndex === selectedMajorTraitIndex,
        index: majorTraitIndex
      });
    })), tier !== 2 && renderTraitLineConnector(path !== undefined ? {
      start: path
    } : {
      disabled: true
    }));
  }))), onReset || !controlled && selectable && resettable && JSON.stringify(uncontrolledSelected) !== JSON.stringify(defaultSelected) && jsx(Tooltip, {
    content: "Reset"
  }, jsx("div", {
    sx: {
      position: 'absolute',
      boxSizing: 'border-box',
      top: 2,
      left: 2,
      cursor: 'pointer'
    }
  }, jsx(Icon, {
    name: "Reset",
    inactive: true,
    sx: {
      fontSize: '32px',
      border: '1px solid rgba(255,255,255,0.5)'
    },
    onClick: function onClick(event) {
      event.preventDefault();

      if (!controlled) {
        setUncontrolledSelected(defaultSelected);
      }

      if (typeof onReset === 'function') {
        onReset();
      }
    }
  }))));
});
TraitLine.propTypes = {
  id: PropTypes.number,
  traitComponent: PropTypes.elementType.isRequired,
  defaultSelected: PropTypes.arrayOf(PropTypes.number),
  selected: PropTypes.arrayOf(PropTypes.number),
  selectable: PropTypes.bool,
  resettable: PropTypes.bool,
  onReset: PropTypes.func,
  onSelect: PropTypes.func,
  data: PropTypes.object.isRequired
};
TraitLine.defaultProps = {
  id: null,
  defaultSelected: [],
  selected: [],
  selectable: true,
  resettable: true,
  onReset: null,
  onSelect: null
};
TraitLine.displayName = 'TraitLine';
export default withLoading({
  iconWithTextProps: {
    sx: {
      width: '100%',
      maxWidth: '650px',
      height: '135px',
      backgroundColor: 'rgba(0,0,0,0.2)',
      border: '1px solid rgb(9, 10, 14)',
      display: 'flex',
      justifyContent: 'center',
      alignItems: 'center',
      fontSize: '34px'
    }
  },
  errorProps: {
    sx: {
      width: '100%',
      maxWidth: '650px',
      height: '135px',
      backgroundColor: 'rgba(0,0,0,0.2)',
      border: '1px solid rgb(9, 10, 14)',
      display: 'flex',
      justifyContent: 'center',
      alignItems: 'center',
      fontSize: '34px'
    }
  }
})(TraitLine);
//# sourceMappingURL=TraitLine.js.map