import _extends from "@babel/runtime/helpers/extends";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React, { forwardRef, useState, useEffect } from 'react';
import PropTypes from 'prop-types';
import useResizeAware from 'react-resize-aware';
import { keyframes } from '@emotion/core';
import traitLineConnectorImage from '../assets/images/trait-line-connector.png';
import { jsx } from "@theme-ui/core";
var move = keyframes({
  from: {
    backgroundPositionX: 0
  },
  to: {
    backgroundPositionX: -300
  }
});
export var Paths = {
  UP: 'up',
  MID: 'mid',
  DOWN: 'down'
};
var TraitLineConnector = forwardRef(function (_ref, ref) {
  var start = _ref.start,
      end = _ref.end,
      disabled = _ref.disabled,
      rest = _objectWithoutProperties(_ref, ["start", "end", "disabled"]);

  var _useResizeAware = useResizeAware(),
      _useResizeAware2 = _slicedToArray(_useResizeAware, 2),
      resizeListener = _useResizeAware2[0],
      _useResizeAware2$ = _useResizeAware2[1],
      width = _useResizeAware2$.width,
      height = _useResizeAware2$.height;

  var _useState = useState({}),
      _useState2 = _slicedToArray(_useState, 2),
      dimensions = _useState2[0],
      setDimensions = _useState2[1];

  useEffect(function () {
    var startY;

    switch (start) {
      case Paths.UP:
        startY = height - 18.5;
        break;

      case Paths.MID:
        startY = height * 0.5;

        if (end === Paths.UP) {
          startY += 4;
        } else if (end === Paths.DOWN) {
          startY -= 4;
        }

        break;

      case Paths.DOWN:
        startY = 18.5;
        break;

      default:
        break;
    }

    var endY;

    switch (end) {
      case Paths.UP:
        endY = height - 18.5;
        break;

      case Paths.MID:
        endY = height * 0.5;

        if (start === Paths.UP) {
          endY += 4;
        } else if (start === Paths.DOWN) {
          endY -= 4;
        }

        break;

      case Paths.DOWN:
        endY = 18.5;
        break;

      default:
        break;
    }

    var length = Math.sqrt(Math.pow(width, 2) + Math.pow(startY - endY, 2));
    setDimensions({
      bottom: (startY + endY) / 2 - 8 / 2,
      left: width / 2 - length / 2,
      length: length,
      angle: Math.atan2(endY - startY, -width) * (180 / Math.PI)
    });
  }, [start, end, width, height]);

  if (!dimensions) {
    return null;
  }

  var bottom = dimensions.bottom,
      left = dimensions.left,
      length = dimensions.length,
      angle = dimensions.angle;
  return jsx("div", _extends({
    sx: {
      position: 'relative'
    }
  }, rest, {
    ref: ref
  }), resizeListener, jsx("div", {
    sx: _objectSpread({
      position: 'absolute'
    }, !disabled && {
      backgroundImage: "url(".concat(traitLineConnectorImage, ")"),
      backgroundRepeat: 'repeat-x',
      animation: "".concat(move.toString(), " 30s linear infinite")
    }),
    css: {
      height: 8,
      bottom: bottom,
      left: left,
      width: length,
      transform: "rotate(".concat(angle, "deg)")
    }
  }));
});
TraitLineConnector.propTypes = {
  start: PropTypes.oneOf(Object.values(Paths)),
  end: PropTypes.oneOf(Object.values(Paths)),
  disabled: PropTypes.bool
};
TraitLineConnector.defaultProps = {
  start: Paths.MID,
  end: Paths.MID,
  disabled: false
};
TraitLineConnector.displayName = 'TraitLineConnector';
export default TraitLineConnector;
//# sourceMappingURL=TraitLineConnector.js.map