import _extends from "@babel/runtime/helpers/extends";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import cx from 'classnames';
import PropTypes from 'prop-types';
import React, { forwardRef } from 'react';
import Error from '../Error';
import { getDisplayName } from '../helpers';
import IconWithText from '../IconWithText';
import { jsx } from "@theme-ui/core";
export default (function () {
  var _ref = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {},
      _ref$component = _ref.component,
      defaultComponent = _ref$component === void 0 ? undefined : _ref$component,
      _ref$disableIcon = _ref.disableIcon,
      defaultDisableIcon = _ref$disableIcon === void 0 ? false : _ref$disableIcon,
      _ref$disableText = _ref.disableText,
      defaultDisableText = _ref$disableText === void 0 ? false : _ref$disableText,
      _ref$disableTooltip = _ref.disableTooltip,
      defaultDisableTooltip = _ref$disableTooltip === void 0 ? false : _ref$disableTooltip,
      _ref$inline = _ref.inline,
      defaultInline = _ref$inline === void 0 ? true : _ref$inline,
      _ref$iconWithTextProp = _ref.iconWithTextProps,
      defaultIconWithTextProps = _ref$iconWithTextProp === void 0 ? {} : _ref$iconWithTextProp,
      _ref$errorProps = _ref.errorProps,
      defaultErrorProps = _ref$errorProps === void 0 ? {} : _ref$errorProps;

  return function (Component) {
    var displayName = getDisplayName(Component);
    var WithLoading = forwardRef(function (_ref2, ref) {
      var loading = _ref2.loading,
          error = _ref2.error,
          errorProps = _ref2.errorProps,
          iconWithTextProps = _ref2.iconWithTextProps,
          rest = _objectWithoutProperties(_ref2, ["loading", "error", "errorProps", "iconWithTextProps"]);

      var _rest = _objectSpread({}, rest),
          id = _rest.id,
          data = _rest.data,
          disableIcon = _rest.disableIcon,
          disableText = _rest.disableText,
          disableTooltip = _rest.disableTooltip,
          inline = _rest.inline,
          iconProps = _rest.iconProps;

      if (loading) {
        return jsx(IconWithText, _extends({
          loading: loading,
          disableIcon: disableIcon,
          disableText: disableText,
          inline: inline
        }, iconWithTextProps, {
          iconProps: _objectSpread({}, iconWithTextProps === null || iconWithTextProps === void 0 ? void 0 : iconWithTextProps.iconProps, {}, iconProps)
        }, {
          style: _objectSpread({}, rest.style, {}, iconWithTextProps === null || iconWithTextProps === void 0 ? void 0 : iconWithTextProps.style),
          className: cx(rest.className, iconWithTextProps.className),
          sx: _objectSpread({}, iconWithTextProps === null || iconWithTextProps === void 0 ? void 0 : iconWithTextProps.sx)
        }));
      }

      if (error || !data) {
        var _error$response, _error$response2, _error$response2$data;

        return jsx(Error, _extends({
          code: (error === null || error === void 0 ? void 0 : error.code) || (error === null || error === void 0 ? void 0 : (_error$response = error.response) === null || _error$response === void 0 ? void 0 : _error$response.status),
          name: "Invalid ".concat(displayName).concat(id ? " ".concat(id) : ''),
          message: "".concat((error === null || error === void 0 ? void 0 : error.name) ? "".concat(error.name, ": ") : '').concat((error === null || error === void 0 ? void 0 : (_error$response2 = error.response) === null || _error$response2 === void 0 ? void 0 : (_error$response2$data = _error$response2.data) === null || _error$response2$data === void 0 ? void 0 : _error$response2$data.text) || (error === null || error === void 0 ? void 0 : error.message) || (!data ? 'No data' : 'Unknown error')).concat(id ? " for ".concat(displayName, " ").concat(id) : ''),
          disableTooltip: disableTooltip,
          disableIcon: disableIcon,
          disableText: disableText,
          inline: inline
        }, errorProps, {
          iconProps: _objectSpread({}, errorProps === null || errorProps === void 0 ? void 0 : errorProps.iconProps, {}, iconProps)
        }, {
          style: _objectSpread({}, rest.style, {}, errorProps === null || errorProps === void 0 ? void 0 : errorProps.style),
          className: cx(rest.className, errorProps.className),
          sx: _objectSpread({}, rest.sx, {}, errorProps === null || errorProps === void 0 ? void 0 : errorProps.sx)
        }));
      }

      return jsx(Component, _extends({}, rest, {
        ref: ref
      }));
    });
    WithLoading.propTypes = {
      id: PropTypes.number,
      component: PropTypes.elementType,
      data: PropTypes.object,
      loading: PropTypes.bool,
      error: PropTypes.shape({
        code: PropTypes.string,
        name: PropTypes.string,
        message: PropTypes.string
      }),
      disableIcon: PropTypes.bool,
      disableText: PropTypes.bool,
      disableTooltip: PropTypes.bool,
      inline: PropTypes.bool,
      iconWithTextProps: PropTypes.object,
      errorProps: PropTypes.object
    };
    WithLoading.defaultProps = {
      id: null,
      data: null,
      loading: false,
      error: null,
      component: defaultComponent,
      disableIcon: defaultDisableIcon,
      disableText: defaultDisableText,
      disableTooltip: defaultDisableTooltip,
      inline: defaultInline,
      iconWithTextProps: defaultIconWithTextProps,
      errorProps: defaultErrorProps
    };
    WithLoading.displayName = "WithLoading(".concat(displayName, ")");
    return WithLoading;
  };
});
//# sourceMappingURL=withLoading.js.map